@@ -2,13 +2,13 @@ context("canvasXpress Web Charts - Genome")
 
 
 test_that("cXgenome1", {
-    message("genome - plot function missing")
+    check_ui_test(cXgenome1())
 })
 
 test_that("cXgenome2", {
-    message("genome - plot function missing")
+    check_ui_test(cXgenome2())
 })
 
 test_that("cXgenome3", {
-    message("genome - plot function missing")
+    check_ui_test(cXgenome3())
 })
